import { BasicColumn, FormSchema } from '/@/components/Table'
//列表数据
export const columns: BasicColumn[] = [
	{
		title: '药材',
		align: 'center',
		dataIndex: 'herbId_dictText',
	},
	// {
	// 	title: '药材名称',
	// 	align: 'center',
	// 	dataIndex: 'herbName',
	// },
	{
		title: '适用设备',
		align: 'center',
		dataIndex: 'eqpType_dictText',
	},
	{
		title: '目标含水率',
		align: 'center',
		dataIndex: 'target',
	},
	{
		title: '投料量',
		align: 'center',
		dataIndex: 'feed',
	},
	{
		title: '预计干燥时间',
		align: 'center',
		dataIndex: 'et',
	},
	{
		title: '热风温度',
		align: 'center',
		dataIndex: 'windTemp',
	},
	{
		title: '环境温度',
		align: 'center',
		dataIndex: 'envTemp',
	},
	{
		title: '环境湿度',
		align: 'center',
		dataIndex: 'envHum',
	},
	{
		title: '荡料延时ms',
		align: 'center',
		dataIndex: 'delay',
	},
	{
		title: '翻料次数',
		align: 'center',
		dataIndex: 'turn',
	},
	// {
	// 	title: '租户id',
	// 	align: 'center',
	// 	dataIndex: 'tenantId',
	// },
]
//查询数据
export const searchFormSchema: FormSchema[] = [
	{
		label: '药材',
		field: 'herbId',
		component: 'JSearchSelect',
		componentProps: {
			dict: 'dry_herb,name,id',
		},
		colProps: { span: 6 },
	},
]
//表单数据
export const formSchema: FormSchema[] = [
	{
		label: '药材',
		field: 'herbId',
		component: 'JSearchSelect',
		componentProps: {
			dict: 'dry_herb,name,id',
		},
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请选择药材!' }]
		},
	},
	// {
	// 	label: '药材名称',
	// 	field: 'herbName',
	// 	component: 'Input',
	// },
	{
		label: '设备类型',
		field: 'eqpType',
		component: 'JSearchSelect',
		componentProps: {
			dict: 'dry_eqp_type,name,id',
		},
		dynamicRules: ({ model, schema }) => {
			return [{ required: true, message: '请设备设备类型!' }]
		},
	},
	{
		label: '目标含水率',
		field: 'target',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => '%',
			}
		},
	},
	{
		label: '投料量',
		field: 'feed',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => '筐',
			}
		},
	},
	{
		label: '预计干燥时间',
		field: 'et',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => '分钟',
			}
		},
	},
	{
		label: '热风温度',
		field: 'windTemp',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => '℃',
			}
		},
	},
	{
		label: '环境温度',
		field: 'envTemp',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => '℃',
			}
		},
	},
	{
		label: '环境湿度',
		field: 'envHum',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => 'rh',
			}
		},
	},
	{
		label: '荡料延时',
		field: 'delay',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => 'ms',
			}
		},
	},
	{
		label: '翻料次数',
		field: 'turn',
		component: 'Input',
		dynamicRules: ({ model, schema }) => {
			return [{ required: false }, { pattern: /^-?\d+\.?\d*$/, message: '请输入数字!' }]
		},
		renderComponentContent: () => {
			return {
				suffix: () => '次',
			}
		},
	},
	// TODO 主键隐藏字段，目前写死为ID
	{
		label: '',
		field: 'id',
		component: 'Input',
		show: false,
	},
]

/**
 * 流程表单调用这个方法获取formSchema
 * @param param
 */
export function getBpmFormSchema(_formData): FormSchema[] {
	// 默认和原始表单保持一致 如果流程中配置了权限数据，这里需要单独处理formSchema
	return formSchema
}
